"use strict";

const fetch = require("isomorphic-unfetch");
const serialize = function(obj) {
    var str = [];
    for (var p in obj)
        if (obj.hasOwnProperty(p)) {
            str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]));
        }
    const result = str.join("&")
    return result.length > 0 ? ('?' + result) : '';
}

module.exports = class Restti {
    constructor(config) {
        this.endpoint = ''
        this.api_key = config.api_key;
        this.basePath = "https://app.restti.com/api";
    }

    get calendars() {
        this.endpoint = '/calendars'
        return this
    }

    get events() {
        this.endpoint = '/events'
        return this
    }

    get clients() {
        this.endpoint = '/clients'
        return this
    }

    get rules() {
        this.endpoint = '/rules'
        return this
    }

    get services() {
        this.endpoint = '/services'
        return this
    }

    getAll(options = {}) {
        return this.request(`${this.endpoint}${serialize(options)}`)
    }

    get(id, options = {}) {
        return this.request(`${this.endpoint}/${id}${serialize(options)}`)
    }

    delete(id) {
        return this.request(`${this.endpoint}/${id}`, { method: 'DELETE' })
    }

    update(id = '', data = {}) {
        return this.request(`${this.endpoint}/${id}`, {
            method: 'PUT',
            body: JSON.stringify(data)
        })
    }

    create(data = {}) {
        return this.request(`${this.endpoint}/${id}`, {
            method: 'POST',
            body: JSON.stringify(data)
        })
    }

    async request(endpoint = "", options = {}) {
        const url = this.basePath + endpoint;

        const headers = {
            "X-Restti-Api-Key": `${this.api_key}`,
            "X-Requested-With": "XMLHttpRequest",
            "Content-type": "application/json",
        };

        const config = {
            headers: headers,
            ...options,
        };

        const result = await fetch(url, config);
        return await result.json()
    }
};
